Decoder

Struct Decoder 

pub struct Decoder { /* private fields */ }
Decode video files and streams.

Example

let decoder = Decoder::new(Path::new("video.mp4")).unwrap();
decoder
    .decode_iter()
    .take_while(Result::is_ok)
    .for_each(|frame| println!("Got frame!"),
);

Implementations

Source

impl Decoder

pub fn new(source: impl Into<Location>) -> Result<Self, Error>

Create a decoder to decode the specified source.

Arguments
  • source - Source to decode.
pub fn time_base(&self) -> AvRational

Get decoder time base.

pub fn duration(&self) -> Result<Time, Error>

Duration of the decoder stream.

pub fn frames(&self) -> Result<u64, Error>

Number of frames in the decoder stream.

pub fn decode_iter( &mut self, ) -> impl Iterator<Item = Result<(Time, Frame), Error>> + '_

Decode frames through iterator interface. This is similar to decode but it returns frames through an infinite iterator.

Example
decoder
    .decode_iter()
    .take_while(Result::is_ok)
    .map(Result::unwrap)
    .for_each(|(ts, frame)| {
        // Do something with frame...
    });
pub fn decode(&mut self) -> Result<(Time, Frame), Error>

Decode a single frame.

Return value

A tuple of the frame timestamp (relative to the stream) and the frame itself.

Example
loop {
    let (ts, frame) = decoder.decode()?;
    // Do something with frame...
}
pub fn decode_raw_iter( &mut self, ) -> impl Iterator<Item = Result<RawFrame, Error>> + '_

Decode frames through iterator interface. This is similar to decode_raw but it returns frames through an infinite iterator.

pub fn decode_raw(&mut self) -> Result<RawFrame, Error>

Decode a single frame and return the raw ffmpeg AvFrame.

Return value

The decoded raw frame as RawFrame.

pub fn seek(&mut self, timestamp_milliseconds: i64) -> Result<(), Error>

Seek in reader.

See Reader::seek for more information.

pub fn seek_to_frame(&mut self, frame_number: i64) -> Result<(), Error>

Seek to specific frame in reader.

See Reader::seek_to_frame for more information.

pub fn seek_to_start(&mut self) -> Result<(), Error>

Seek to start of reader.

See Reader::seek_to_start for more information.

pub fn into_parts(self) -> (DecoderSplit, Reader, usize)

Split the decoder into a decoder (of type DecoderSplit) and a Reader.

This allows the caller to detach stream reading from decoding, which is useful for advanced use cases.

Return value

Tuple of the DecoderSplit, Reader and the reader stream index.

pub fn size(&self) -> (u32, u32)

Get the decoders input size (resolution dimensions): width and height.

pub fn size_out(&self) -> (u32, u32)

Get the decoders output size after resizing is applied (resolution dimensions): width and height.

pub fn frame_rate(&self) -> f32

Get the decoders input frame rate as floating-point value.