Aligned

Struct Aligned 

pub struct Aligned { /* private fields */ }
This is a virtual object that represents two aligned times.

On this object, arthmetic operations can be performed that operate on the two contained times. This virtual object ensures that the interface to these operations is safe.

Implementations

Source

impl Aligned

pub fn add(self) -> Time

Add two timestamps together.

pub fn subtract(self) -> Time

Subtract the right-hand side timestamp from the left-hand side timestamp.