DecoderSplit

Struct DecoderSplit 

pub struct DecoderSplit { /* private fields */ }
Decoder part of a split Decoder and Reader.

Important note: Do not forget to drain the decoder after the reader is exhausted. It may still contain frames. Run drain_raw() or drain() in a loop until no more frames are produced.

Implementations

Source

impl DecoderSplit

pub fn new( reader: &Reader, reader_stream_index: usize, resize: Option<Resize>, hwaccel_device_type: Option<HardwareAccelerationDeviceType>, ) -> Result<Self, Error>

Create a new DecoderSplit.

Arguments
  • reader - Reader to initialize decoder from.
  • resize - Optional resize strategy to apply to frames.
pub fn time_base(&self) -> AvRational

Get decoder time base.

pub fn decode(&mut self, packet: Packet) -> Result<Option<(Time, Frame)>, Error>

Decode a Packet.

Feeds the packet to the decoder and returns a frame if there is one available. The caller should keep feeding packets until the decoder returns a frame.

Panics

Panics if in draining mode.

Return value

A tuple of the Frame and timestamp (relative to the stream) and the frame itself if the decoder has a frame available, None if not.

pub fn decode_raw(&mut self, packet: Packet) -> Result<Option<RawFrame>, Error>

Decode a Packet.

Feeds the packet to the decoder and returns a frame if there is one available. The caller should keep feeding packets until the decoder returns a frame.

Panics

Panics if in draining mode.

Return value

The decoded raw frame as RawFrame if the decoder has a frame available, None if not.

pub fn drain(&mut self) -> Result<Option<(Time, Frame)>, Error>

Drain one frame from the decoder.

After calling drain once the decoder is in draining mode and the caller may not use normal decode anymore or it will panic.

Return value

A tuple of the Frame and timestamp (relative to the stream) and the frame itself if the decoder has a frame available, None if not.

pub fn drain_raw(&mut self) -> Result<Option<RawFrame>, Error>

Drain one frame from the decoder.

After calling drain once the decoder is in draining mode and the caller may not use normal decode anymore or it will panic.

Return value

The decoded raw frame as RawFrame if the decoder has a frame available, None if not.

pub fn reset(&mut self)

Reset the decoder to be used again after draining.

pub fn size(&self) -> (u32, u32)

Get the decoders input size (resolution dimensions): width and height.

pub fn size_out(&self) -> (u32, u32)

Get the decoders output size after resizing is applied (resolution dimensions): width and height.