pub struct Aligned { /* private fields */ }Expand description
This is a virtual object that represents two aligned times.
On this object, arthmetic operations can be performed that operate on the two contained times. This virtual object ensures that the interface to these operations is safe.
Implementations